-- Tests for HazLootList functions, especially the loot comparator

require("HazLootList")
require("WoWMock")
require("Core")

function TestSetup()
  print("*** Setting up HazLootList tests")
  print("*** Setup succeeded")
end

function TestTeardown()
  print("*** Tearing down HazLootList tests")
  print("*** Teardown succeeded")
end

function TestAddItem()
  print("*** Testing AddItem()")
  assert(-1 == HLL:AddItem(), "Expected to fail adding a nil item")
  assert(-1 == HLL:AddItem(""), "Expected to fail adding an empty item")
  assert(1  == HLL:AddItem(WM.ITEMS[1].itemrolestring), "Expected to be able to add role-less '"..WM.ITEMS[1].name.."'")
  assert(2  == HLL:AddItem(WM.ITEMS[2].itemrolestring), "Expected to be able to add role-less '"..WM.ITEMS[2].name.."', with separator")
  assert(-1 == HLL:AddItem("Item3|BadRole"), "Expected to fail adding Item3 with bad role")
  assert(-1 == HLL:AddItem("Item3|BadRole:Druid"), "Expected to fail adding Item3 with bad role and restriction")
  assert(-1 == HLL:AddItem("Item3|Healer:Magician"), "Expected to fail adding Item3 with good role and bad restriction")
  for i=3,10 do
    assert(i  == HLL:AddItem(WM.ITEMS[i].itemrolestring), "Expected to be able to add role-less '"..WM.ITEMS[i].name.."'")
  end
  assert(-1 == HLL:AddItem("Item10|Physical DPS:Druid,Tank:Fat Bastard"), "Expected to fail adding 'Item10|Physical DPS:Druid,Tank:Fat Bastard")
  assert(-1 == HLL:AddItem("Item10|Physical DPS:Fat Bastard,Tank:Druid"), "Expected to fail adding 'Item10|Physical DPS:Fat Bastard,Tank:Druid")
  assert(11  == HLL:AddItem(WM.ITEMS[11].itemrolestring), "Expected to be able to add '"..WM.ITEMS[11].name.."'")
  assert(11 == HLL:AddItem(WM.ITEMS[11].name.."|Random roll"), "Expected to be able to overwrite '"..WM.ITEMS[11].name.."|Random roll'")
  assert(11  == HLL:AddItem(WM.ITEMS[11].itemrolestring), "Expected to be able to restor '"..WM.ITEMS[11].name.."'")
  assert(11 == HLL:HowMuchLoot(),"I should have 11 pieces of loot")
  print("*** AddItem() seems to work as expected")
end

function TestLootSort()
  print("*** Testing Loot Sort")
  WM:CreateBigBagOLoot()
  HLL:Sort(WM.BigLootSet)
  HazLoot:ShowMeLoot(WM.BigLootSet)
  print("*** Loot Sort seems to work as expected")
end

TestSetup()
TestAddItem()
TestLootSort()
TestTeardown()

--[[ TEMPLATE

function TestXXX()
  print("*** Testing XXX()")
  print("*** XXX() seems to work as expected")
end

-- ]]--
